@@ -2,7 +2,7 @@
 
 # Meta
 
-__version__ = "0.0.2"
+__version__ = "0.0.4"
 __author__ = 'Rhys Elsmore'
 __email__ = 'me@rhys.io'
 __license__ = 'Apache 2.0'
@@ -10,6 +10,6 @@ __copyright__ = 'Copyright 2014 Rhys Elsmore'
 
 # Module Namespace
 
-from .core import LogMetrics
-from .api import timer, increment, sample, measure, unique
+from .core import MetricsLogger, GroupMetricsLogger
+from .api import timer, increment, sample, measure, unique, group
 
